@@ -22,7 +22,6 @@ use.cox.path <- function(x, y) {
         length(unique(attr(y, "strata"))) == 1)
       use_cox_path <- FALSE
   }
-
   # if strata provided in y but y not of class stratifySurv, throw error
   if ("strata" %in% names(attributes(y)) && !inherits(y, "stratifySurv"))
     stop(paste0("For fitting stratified Cox models, y must be of class ",
@@ -452,7 +451,7 @@ cox.path <- function(x, y, weights=NULL, offset=NULL,
 #' in the model.}
 #' \item{call}{The call that produced this object.}
 #' \item{nobs}{Number of observations.}
-#' \item{warm_fit}{If \code{save.fit=TRUE}, output of FORTRAN routine, used for
+#' \item{warm_fit}{If \code{save.fit=TRUE}, output of C++ routine, used for
 #' warm starts. For internal use only.}
 #' \item{family}{Family used for the model, always "cox".}
 #' \item{converged}{A logical variable: was the algorithm judged to have
@@ -524,13 +523,13 @@ cox.fit <- function(x, y, weights, lambda, alpha = 1.0, offset = rep(0, nobs),
     coefold <- rep(0, nvars)   # initial coefs = 0
     eta <- offset
   } else {
-    if ("glmnetfit" %in% class(warm)) {
-      if (class(warm$warm_fit) != "warmfit") stop("Invalid warm start object")
+    if (inherits(warm,"glmnetfit")) {
+      if (!is(warm$warm_fit,"warmfit")) stop("Invalid warm start object")
       fit <- warm
       nulldev <- fit$nulldev
       coefold <- fit$warm_fit$a  # prev value for coefficients
       eta <- get_eta(x, coefold, 0) + offset
-    } else if ("list" %in% class(warm) && "beta" %in% names(warm)) {
+    } else if (inherits(warm,"list") && "beta" %in% names(warm)) {
       fit <- warm
       nulldev <- coxnet.deviance(y = y, offset = offset, weights = weights,
                                  std.weights = FALSE)
