@@ -26,10 +26,14 @@
 #' factory default = 100
 #' @param itrace If 1 then progress bar is displayed when running \code{glmnet}
 #' and \code{cv.glmnet}. factory default = 0
+#' @param epsnr convergence threshold for \code{glmnet.fit}. factory default =
+#' 1.0e-6
+#' @param mxitnr maximum iterations for the IRLS loop in \code{glmnet.fit}. factory
+#' default = 25
 #' @param factory If \code{TRUE}, reset all the parameters to the factory
 #' default; default is \code{FALSE}
 #' @return A list with named elements as in the argument list
-#' @author Jerome Friedman, Trevor Hastie\cr Maintainer: Trevor Hastie
+#' @author Jerome Friedman, Kenneth Tay, Trevor Hastie\cr Maintainer: Trevor Hastie
 #' \email{hastie@@stanford.edu}
 #' @seealso \code{glmnet}
 #' @keywords models regression
@@ -43,40 +47,44 @@
 glmnet.control <-
   function (fdev = 1e-05, devmax = 0.999, eps = 1e-06, big = 9.9e+35,
             mnlam = 5, pmin = 1e-09, exmx = 250, prec = 1e-10, mxit = 100,
-            itrace = 0, factory = FALSE)
+            itrace = 0, epsnr = 1e-06, mxitnr = 25, factory = FALSE)
 {
   inquiry=!nargs()
    if (factory)
     invisible(glmnet.control(fdev = 1e-05, devmax = 0.999,
                              eps = 1e-06, big = 9.9e+35, mnlam = 5, pmin = 1e-09,
-                             exmx = 250, prec = 1e-10, mxit = 100, itrace = 0))
+                             exmx = 250, prec = 1e-10, mxit = 100, itrace = 0,
+                             epsnr = 1e-06, mxitnr = 25))
   else {
     if (!missing(fdev))
-      .Fortran("chg_fract_dev", as.double(fdev), PACKAGE = "glmnet")
+      chg_fract_dev(as.double(fdev))
     if (!missing(devmax))
-      .Fortran("chg_dev_max", as.double(devmax), PACKAGE = "glmnet")
+      chg_dev_max(as.double(devmax))
     if (!missing(eps))
-      .Fortran("chg_min_flmin", as.double(eps), PACKAGE = "glmnet")
+      chg_min_flmin(as.double(eps))
     if (!missing(big))
-      .Fortran("chg_big", as.double(big), PACKAGE = "glmnet")
+      chg_big(as.double(big))
     if (!missing(mnlam))
-      .Fortran("chg_min_lambdas", as.integer(mnlam), PACKAGE = "glmnet")
+      chg_min_lambdas(as.integer(mnlam))
     if (!missing(pmin))
-      .Fortran("chg_min_null_prob", as.double(pmin), PACKAGE = "glmnet")
+      chg_min_null_prob(as.double(pmin))
     if (!missing(exmx))
-      .Fortran("chg_max_exp", as.double(exmx), PACKAGE = "glmnet")
+      chg_max_exp(as.double(exmx))
     if (!missing(prec) | !missing(mxit))
-      .Fortran("chg_bnorm", as.double(prec), as.integer(mxit),
-               PACKAGE = "glmnet")
+      chg_bnorm(as.double(prec), as.integer(mxit))
     if (!missing(itrace))
-      .Fortran("chg_itrace", as.integer(itrace), PACKAGE = "glmnet")
+      chg_itrace(as.integer(itrace))
+    if (!missing(epsnr))
+        chg_epsnr(as.double(epsnr))
+    if (!missing(mxitnr))
+        chg_mxitnr(as.integer(mxitnr))
 
-    value=c(.Fortran("get_int_parms", fdev = double(1),
-                         eps = double(1), big = double(1), mnlam = integer(1),
-                         devmax = double(1), pmin = double(1), exmx = double(1),
-                         itrace = integer(1),
-                         PACKAGE = "glmnet"), .Fortran("get_bnorm", prec = double(1),
-                           mxit = integer(1), PACKAGE = "glmnet"))
+    value=c(get_int_parms(fdev = double(1),
+                     eps = double(1), big = double(1), mnlam = integer(1),
+                     devmax = double(1), pmin = double(1), exmx = double(1),
+                     itrace = integer(1)),
+            get_bnorm(prec = double(1), mxit = integer(1)),
+            get_int_parms2(epsnr = double(1), mxitnr = integer(1)))
     if(inquiry)value else invisible(value)
   }
 }
